#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-cairo
version:                1.0.30
visibility:             public
id:                     gi-cairo-1.0.30-GKyt41nPYHRI3P8LgREFdP
key:                    gi-cairo-1.0.30-GKyt41nPYHRI3P8LgREFdP
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Cairo bindings
description:            Bindings for Cairo, autogenerated by haskell-gi.
category:               Bindings
abi:                    b8cc31980af0505c417888a85add2774
exposed:                True
exposed-modules:
    GI.Cairo GI.Cairo.Config GI.Cairo.Enums GI.Cairo.Functions
    GI.Cairo.Structs GI.Cairo.Structs.Context GI.Cairo.Structs.Device
    GI.Cairo.Structs.FontFace GI.Cairo.Structs.FontOptions
    GI.Cairo.Structs.Glyph GI.Cairo.Structs.Matrix
    GI.Cairo.Structs.Path GI.Cairo.Structs.Pattern
    GI.Cairo.Structs.Rectangle GI.Cairo.Structs.RectangleInt
    GI.Cairo.Structs.Region GI.Cairo.Structs.ScaledFont
    GI.Cairo.Structs.Surface GI.Cairo.Structs.TextCluster

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-cairo-1.0.30
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-cairo-1.0.30 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-cairo-1.0.30 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-cairo
hs-libraries:           HSgi-cairo-1.0.30-GKyt41nPYHRI3P8LgREFdP
extra-libraries:        cairo-gobject cairo gobject-2.0 glib-2.0
extra-libraries-static:
    cairo-gobject m dl cairo m dl gobject-2.0 glib-2.0 atomic m
    sysprof-capture-4 pcre2-8 pthread ffi fontconfig m expat m freetype
    dl bz2 png16 m m z brotlidec brotlicommon Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m

include-dirs:
    /usr/include/cairo /usr/include /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-6
    /usr/include/freetype2 /usr/include/libpng16 /usr/include/pixman-1

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    haskell-gi-0.26.17-8JFBf5L4fuwFdV2u3KLSL6
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-cairo/html/gi-cairo.haddock
haddock-html:           /usr/share/doc/haskell-gi-cairo/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

